==============
Notebooks
==============


Basic
-----
.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/basics/*

Advanced
--------
.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/advanced/*

Tailor
------
.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/tailor/*

Theory
------
.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/theory/*

Understanding
-------------
.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/understanding/*
